@@ -1,7 +1,11 @@
 from typing import Union
 
 from pydantic import validator
-from typing_extensions import Literal
+
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
 
 from ..structures.distinct import Distinct
 from ..functions.base import BaseFunction
